//-------------------------------------------------------------------------
// This example macro demonstrates one way to operate on multiple blocks of
// lines identified by label ranges.
//
// Labels must be specified prior to macro execution.
//
// Labels must be in matched pairs from letter set A..Z.
//
// First pair .A and .B, second pair .C and .D, etc. (Up to 13 pairs)
//
// NOTE: This macro terminates normally with a "Label not found" short
// message, please ignore that.
// 
//-------------------------------------------------------------------------
void DoByLbl(int argc, char *argv[]) {

  char *letters[];
  int   linenum1, linenum2;
  int   letter_index = 0;
  int   cur_linenum, new_linenum;
  int   label_count = 0;
  BOOL  any_pair_found = FALSE;
  BOOL  done = FALSE;
   
  //------------------------
  // initialize letter array
  //------------------------
  letters[0]  = "A";
  letters[1]  = "B";
  letters[2]  = "C";
  letters[3]  = "D";
  letters[4]  = "E";
  letters[5]  = "F";
  letters[6]  = "G";
  letters[7]  = "H";
  letters[8]  = "I";
  letters[9]  = "J";
  letters[10] = "K";
  letters[11] = "L";
  letters[12] = "M";
  letters[13] = "N";
  letters[14] = "O";
  letters[15] = "P";
  letters[16] = "Q";
  letters[17] = "R";
  letters[18] = "S";
  letters[19] = "T";
  letters[20] = "U";
  letters[21] = "V";
  letters[22] = "W";
  letters[23] = "X";
  letters[24] = "Y";
  letters[25] = "Z";
   
  //-----------------
  // find label pairs
  //-----------------
  while (!done) {
    cur_linenum = SPFservice("query","line_number");
    SPFservice("cmd",strcompose("locate .",letters[letter_index]);
    new_linenum = SPFservice("query","line_number");
    if (new_linenum != cur_linenum) {
      // found a label, save its line number
      ++label_count;
      if (linenum1 == 0)
        linenum1 = new_linenum;
      else
        linenum2 = new_linenum;
      if (linenum2 != 0) {
        //-----------------
        // label pair found
        //-----------------
        any_pair_found = TRUE;
        ApplyOperation(linenum1,linenum2);
        linenum1 = 0; // reset
        linenum2 = 0; // reset
      }
      if (letter_index >= 25) {
        done = TRUE;
        }
      else {
        ++letter_index; // step to next letter
      }
      }
    else {
      done = TRUE;
    }
  } // while
  if (!any_pair_found) {
    Msg("Specify at least one pair of labels from letter set A..Z prior to macro execution.");
    }
  else {
    if ((label_count % 2) != 0) { 
      Msg(strcompose("Label on line number ",linenum1," has no pair.");
    }
  }

} // DoByLbl
 
void ApplyOperation(int linenum1, int linenum2) {
 
  // In this function you apply whatever operation you see fit to the subject
  // line block.
  Msg(strcompose("Applying operation to lines ",linenum1," through ",linenum2));
 
} // ApplyOperation
